package cn.com.qmth.examcloud.exchange.config;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurerAdapter;

import cn.com.qmth.examcloud.commons.base.util.PathUtil;
import cn.com.qmth.examcloud.commons.base.util.PropertiesUtil;
import cn.com.qmth.examcloud.commons.web.interceptor.FirstInterceptor;
import cn.com.qmth.examcloud.commons.web.redis.RedisClient;
import cn.com.qmth.examcloud.commons.web.security.RequestPermissionInterceptor;
import cn.com.qmth.examcloud.commons.web.security.bean.User;

/**
 * 默认WebMvcConfigurer
 *
 * @author WANGWEI
 * @date 2018年5月22日
 * @Copyright (c) 2018-? http://qmth.com.cn All Rights Reserved.
 */
@Configuration
public class DefaultWebMvcConfigurerAdapter extends WebMvcConfigurerAdapter {

	@Autowired
	RedisClient redisClient;

	static {
		PropertiesUtil.configureAndWatch(PathUtil.getResoucePath("security-mapping.properties"));
	}

	@Override
	public void addInterceptors(InterceptorRegistry registry) {
		registry.addInterceptor(new FirstInterceptor()).addPathPatterns("/**");
		RequestPermissionInterceptor requestPermissionInterceptor = getRequestPermissionInterceptor();
		requestPermissionInterceptor.configureAndWatch("security-exclusions.conf");
		registry.addInterceptor(requestPermissionInterceptor).addPathPatterns("/**");
		super.addInterceptors(registry);
	}

	@Bean
	public RequestPermissionInterceptor getRequestPermissionInterceptor() {
		return new RequestPermissionInterceptor(redisClient) {

			@Override
			public boolean hasPermission(String mappingPath, User user) {
				return true;
			}

		};
	}
}
